/*$Id: l_trim.cc,v 18.5 2000/07/10 08:36:32 al Exp $ -*- C++ -*-
 * remove whitespace from the end of strings
 */
#include <ctype.h>
/*--------------------------------------------------------------------------*/
	char*	trim(char*);
/*--------------------------------------------------------------------------*/
char* trim(char *string)
{
  int idx = strlen(string);
  while (idx > 0  &&  !isgraph(string[--idx]))
    string[idx] = '\0' ;
  return string;
}
/*--------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/
